==> ejc-sale-impl-3.0.0-20220404.055637-20-sources.jar: com/ejianc/business/sale/bean/PaymentdetialEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 付款管理子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_paymentdetial")
public class PaymentdetialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; // 
    @TableField(value="consignment_date")
    private Date consignmentDate; // 发货年月
    @TableField(value="payment_money")
    private BigDecimal paymentMoney; // 应付金额
    @TableField(value="paid_money")
    private BigDecimal paidMoney; // 本单已付金额
    @TableField(value="other_paid_money")
    private BigDecimal otherPaidMoney; // 其他单已付金额
    @TableField(value="outstanding_money")
    private BigDecimal outstandingMoney; // 未付金额
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }
    public Date getConsignmentDate() {
        return consignmentDate;
    }

    public void setConsignmentDate(Date consignmentDate) {
        this.consignmentDate = consignmentDate;
    }
    public BigDecimal getPaymentMoney() {
        return paymentMoney;
    }

    public void setPaymentMoney(BigDecimal paymentMoney) {
        this.paymentMoney = paymentMoney;
    }
    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }
    public BigDecimal getOtherPaidMoney() {
        return otherPaidMoney;
    }

    public void setOtherPaidMoney(BigDecimal otherPaidMoney) {
        this.otherPaidMoney = otherPaidMoney;
    }
    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }
    
}

==> ejc-sale-impl-3.0.0-20220614.082416-158-sources.jar: com/ejianc/business/sale/bean/PaymentdetialEntity.java <==
package com.ejianc.business.sale.bean;

import java.util.Date;
import java.math.*;
import java.util.List;
import java.util.ArrayList;
import java.io.Serializable;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;
import com.ejianc.framework.skeleton.template.annotation.SubEntity;

/**
 * 付款管理子表
 * 
 * @author generator
 * 
 */
 @TableName("ejc_sale_paymentdetial")
public class PaymentdetialEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;
    
    @TableField(value="mid")
    private Long mid; //
    @TableField(value="bill_code")
    private String billCode; // 单据编号
    @TableField(value="consignment_date")
    private Date consignmentDate; // 发货年月
    @TableField(value="payment_money")
    private BigDecimal paymentMoney; // 应付金额
    @TableField(value="paid_money")
    private BigDecimal paidMoney; // 本单已付金额
    @TableField(value="other_paid_money")
    private BigDecimal otherPaidMoney; // 其他单已付金额
    @TableField(value="outstanding_money")
    private BigDecimal outstandingMoney; // 未付金额
    @TableField(value="distribution_money")
    private BigDecimal distributionMoney; // 分配金额
    @TableField(value="bill_state")
    private Integer billState; // 单据状态: 0自由态,1已提交,2审批中,3审批通过,4驳回,5提交后有人审批中
    @TableField(value="org_id")
    private Long orgId; // 所属组织id
    @TableField(value="org_name")
    private String orgName; // 所属组织名称
    @TableField(value="manualshipment_id")
    private Long manualshipmentId; //发货单id
    
    
    

    public Long getMid() {
        return mid;
    }

    public void setMid(Long mid) {
        this.mid = mid;
    }

    public String getBillCode() {
        return billCode;
    }

    public void setBillCode(String billCode) {
        this.billCode = billCode;
    }

    public Date getConsignmentDate() {
        return consignmentDate;
    }

    public void setConsignmentDate(Date consignmentDate) {
        this.consignmentDate = consignmentDate;
    }
    public BigDecimal getPaymentMoney() {
        return paymentMoney;
    }

    public void setPaymentMoney(BigDecimal paymentMoney) {
        this.paymentMoney = paymentMoney;
    }
    public BigDecimal getPaidMoney() {
        return paidMoney;
    }

    public void setPaidMoney(BigDecimal paidMoney) {
        this.paidMoney = paidMoney;
    }
    public BigDecimal getOtherPaidMoney() {
        return otherPaidMoney;
    }

    public void setOtherPaidMoney(BigDecimal otherPaidMoney) {
        this.otherPaidMoney = otherPaidMoney;
    }
    public BigDecimal getOutstandingMoney() {
        return outstandingMoney;
    }

    public void setOutstandingMoney(BigDecimal outstandingMoney) {
        this.outstandingMoney = outstandingMoney;
    }
    public BigDecimal getDistributionMoney() {
        return distributionMoney;
    }

    public void setDistributionMoney(BigDecimal distributionMoney) {
        this.distributionMoney = distributionMoney;
    }
    public Integer getBillState() {
        return billState;
    }

    public void setBillState(Integer billState) {
        this.billState = billState;
    }
    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }
    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getManualshipmentId() {
        return manualshipmentId;
    }

    public void setManualshipmentId(Long manualshipmentId) {
        this.manualshipmentId = manualshipmentId;
    }
}
